@@ -1,7 +1,8 @@
 """ **Description**
 
         A serial instance encodes and decodes an instance or collection with
-        JSON, or base-64 encoded gzip JSON binary format.
+        JSON, or base-85 encoded gzip JSON binary format using the jsonpickle
+        package.
 
         An instance may be an object or a collection, referenced by abstract or
         concrete types, and the instance will be correctly encoded and decoded.
@@ -14,6 +15,8 @@
 
         Singleton.
 
+        Thread safe.
+
     **Example**
 
         ::
@@ -25,8 +28,7 @@
 
             # Encode and decode a dictionary instance in JSON.
 
-            x = { 'a' : numpy.random.rand( count ),
-                  'b' : list( numpy.random.rand( count ) ) }
+            x = { 'a' : numpy.random.rand( count ), 'b' : list( numpy.random.rand( count ) ) }
 
             z = Serial.decode( Serial.encode( x ) )
 
@@ -46,13 +48,9 @@
 
             z = Serial.decode( '{ "a" : 1.0, "b" : 2.0, "c" : 3.14159 }' )
 
-            # Decode a dictionary instance from JSON, and clean comments.
-
-            z = Serial.decode( '{ "a" : 1.0, "b" : 2.0, "c" : 3.14159 }  # Comments.\n', clean = True )
-
     **License**
 
-        `BSD-3C. <https://github.com/larryturner/diamondback/blob/master/license>`_
+        `BSD-3C.  <https://github.com/larryturner/diamondback/blob/master/license>`_
 
         Copyright (c) 2018, Larry Turner, Schneider Electric.  All rights reserved.
 
@@ -66,6 +64,7 @@
 
 import base64
 import gzip
+import hashlib
 import jsonpickle
 import jsonpickle.ext.numpy
 import jsonpickle.ext.pandas
@@ -74,17 +73,43 @@ import re
 
 class Serial( object ) :
 
-    """ Serial service, with JSON or base-64 encoded gzip JSON binary format.
+    """ Serial service, with JSON or base-85 encoded gzip JSON binary format.
     """
 
     jsonpickle.ext.numpy.register_handlers( )
 
     jsonpickle.ext.pandas.register_handlers( )
 
+    @staticmethod
+    def code( state : str, encoding : str = 'utf_8' ) -> str :
+
+        """ Code generation.  SHA3-256 hash.
+
+            Arguments :
+
+                state - State ( str ).
+
+                encoding - Encoding ( str ).
+
+            Returns :
+
+                code - Code ( str ).
+        """
+
+        if ( not state ) :
+
+            raise ValueError( f'State = {state}' )
+
+        if ( not encoding ) :
+
+            raise ValueError( f'Encoding = {encoding}' )
+
+        return hashlib.sha3_256( bytes( state, encoding ) ).hexdigest( )
+
     @staticmethod
     def decode( state : str, compress : bool = False, encoding : str = 'utf_8', clean : bool = False ) -> any :
 
-        """ Decodes an instance or collection from JSON, or base-64 encoded
+        """ Decodes an instance or collection from JSON, or base-85 encoded
             gzip JSON binary format state.  Encoding may be specified if an
             alternative to UTF-8 is required.  Python style docstring and line
             comments may be cleaned, though line comments must be terminated by
@@ -107,15 +132,15 @@ class Serial( object ) :
 
         if ( not state ) :
 
-            raise ValueError( 'State = ' + str( state ) )
+            raise ValueError( f'State = {state}' )
 
         if ( not encoding ) :
 
-            raise ValueError( 'Encoding = ' + str( encoding ) )
+            raise ValueError( f'Encoding = {encoding}' )
 
         if ( compress ) :
 
-            state = str( gzip.decompress( base64.b64decode( bytes( state, encoding ) ) ), encoding )
+            state = str( gzip.decompress( base64.b85decode( bytes( state, encoding ) ) ), encoding )
 
         if ( clean ) :
 
@@ -126,7 +151,7 @@ class Serial( object ) :
     @staticmethod
     def encode( instance : any, compress : bool = False, encoding : str = 'utf_8' ) -> str :
 
-        """ Encodes JSON, or base-64 encoded gzip JSON binary format state from
+        """ Encodes JSON, or base-85 encoded gzip JSON binary format state from
             an instance or collection.  Encoding may be specified if an
             alternative to UTF-8 is required.
 
@@ -145,12 +170,12 @@ class Serial( object ) :
 
         if ( not encoding ) :
 
-            raise ValueError( 'Encoding = ' + str( encoding ) )
+            raise ValueError( f'Encoding = {encoding}' )
 
-        state = jsonpickle.encode( instance )
+        state = jsonpickle.encode( instance, separators = ( ',', ':' ) )
 
         if ( compress ) :
 
-            state = str( base64.b64encode( gzip.compress( bytes( state, encoding ) ) ), encoding )
+            state = str( base64.b85encode( gzip.compress( bytes( state, encoding ) ) ), encoding )
 
         return state
