@@ -51,13 +51,13 @@
 
             # Filter an incident signal.
 
-            x = ComplexExponentialFilter( 0.0 ).filter( numpy.ones( 1024 ) * frequency ) * numpy.random.rand( 1 )[ 1 ]
+            x = ComplexExponentialFilter( 0.0 ).filter( numpy.ones( 1024 ) * frequency ) * numpy.random.rand( 1 )[ 0 ]
 
             y = obj.filter( x )
 
     **License**
 
-        `BSD-3C. <https://github.com/larryturner/diamondback/blob/master/license>`_
+        `BSD-3C.  <https://github.com/larryturner/diamondback/blob/master/license>`_
 
         Copyright (c) 2018, Larry Turner, Schneider Electric.  All rights reserved.
 
@@ -82,7 +82,7 @@ class GoertzelFilter( IirFilter, IFrequency ) :
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
@@ -112,7 +112,7 @@ class GoertzelFilter( IirFilter, IFrequency ) :
 
         if ( ( len( b.shape ) != 1 ) or ( len( b ) == 0 ) or ( not b.any( ) ) ) :
 
-            raise ValueError( 'B = ' + str( b ) )
+            raise ValueError( f'B = {b}' )
 
         u = numpy.array( [ 0.0, 2.0 * math.cos( math.pi * frequency ), -1.0 ] )
 
@@ -145,7 +145,7 @@ class GoertzelFilter( IirFilter, IFrequency ) :
 
         if ( ( len( x.shape ) != 1 ) or ( len( x ) == 0 ) ) :
 
-            raise ValueError( 'X = ' + str( x ) )
+            raise ValueError( f'X = {x}' )
 
         y = numpy.zeros( int( numpy.ceil( len( x ) / len( self._w ) ) ) + 1, complex )
 
@@ -155,7 +155,7 @@ class GoertzelFilter( IirFilter, IFrequency ) :
 
         for ii in range( 0, len( x ) ) :
 
-            v = super( ).filter( u * self._w[ self._index ] * x[ ii : ii + 1 ] )[ 0 ]
+            v = super( ).filter( u * self._w[ self._index ] * x[ ii : ii + 1 ] )
 
             self._index += 1
 
