@@ -32,7 +32,7 @@
 
     **License**
 
-        `BSD-3C. <https://github.com/larryturner/diamondback/blob/master/license>`_
+        `BSD-3C.  <https://github.com/larryturner/diamondback/blob/master/license>`_
 
         Copyright (c) 2018, Larry Turner, Schneider Electric.  All rights reserved.
 
@@ -66,13 +66,13 @@ class PidFilter( FirFilter ) :
 
         if ( limit < 0.0 ) :
 
-            raise ValueError( 'Limit = ' + str( limit ) )
+            raise ValueError( f'Limit = {limit}' )
 
         self._limit = limit
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
@@ -100,9 +100,9 @@ class PidFilter( FirFilter ) :
 
         if ( ( len( b.shape ) != 1 ) or ( len( b ) != 3 ) ) :
 
-            raise ValueError( 'B = ' + str( b ) )
+            raise ValueError( f'B = {b}' )
 
-        super( ).__init__( b, numpy.zeros( len( b ) ), 0.0 )
+        super( ).__init__( b, numpy.zeros( len( b ) ) )
 
         self._limit = float( 'inf' )
 
@@ -125,7 +125,7 @@ class PidFilter( FirFilter ) :
 
         if ( ( len( x.shape ) != 1 ) or ( len( x ) == 0 ) ) :
 
-            raise ValueError( 'X = ' + str( x ) )
+            raise ValueError( f'X = {x}' )
 
         y = numpy.zeros( len( x ), type( self.b[ 0 ] ) )
 
