@@ -44,7 +44,7 @@
 
     **License**
 
-        `BSD-3C. <https://github.com/larryturner/diamondback/blob/master/license>`_
+        `BSD-3C.  <https://github.com/larryturner/diamondback/blob/master/license>`_
 
         Copyright (c) 2018, Larry Turner, Schneider Electric.  All rights reserved.
 
@@ -78,7 +78,7 @@ class PolynomialRateFilter( IRate ) :
 
         if ( order < 2 ) :
 
-            raise ValueError( 'Order = ' + str( order ) )
+            raise ValueError( f'Order = {order}' )
 
         self._order = order
 
@@ -90,7 +90,7 @@ class PolynomialRateFilter( IRate ) :
 
         if ( rate <= 0.0 ) :
 
-            raise ValueError( 'Rate = ' + str( rate ) )
+            raise ValueError( f'Rate = {rate}' )
 
         if ( not numpy.isclose( self.rate, rate ) ) :
 
@@ -100,7 +100,7 @@ class PolynomialRateFilter( IRate ) :
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
@@ -126,7 +126,7 @@ class PolynomialRateFilter( IRate ) :
 
         if ( order < 2 ) :
 
-            raise ValueError( 'Order = ' + str( order ) )
+            raise ValueError( f'Order = {order}' )
 
         super( ).__init__( )
 
@@ -153,7 +153,7 @@ class PolynomialRateFilter( IRate ) :
 
         if ( ( len( x.shape ) != 1 ) or ( len( x ) < 2 ) ) :
 
-            raise ValueError( 'X = ' + str( x ) )
+            raise ValueError( f'X = {x}' )
 
         cc = len( x )
 
