@@ -77,7 +77,7 @@
 
     **License**
 
-        `BSD-3C. <https://github.com/larryturner/diamondback/blob/master/license>`_
+        `BSD-3C.  <https://github.com/larryturner/diamondback/blob/master/license>`_
 
         Copyright (c) 2018, Larry Turner, Schneider Electric.  All rights reserved.
 
@@ -122,7 +122,7 @@ class PolyphaseRateFilter( IB, IRate, IReset, IS ) :
 
         if ( ( rate <= 0.0 ) or ( rate > count ) ) :
 
-            raise ValueError( 'Rate = ' + str( rate ) )
+            raise ValueError( f'Rate = {rate}' )
 
         if ( not numpy.isclose( self.rate, rate ) ) :
 
@@ -132,7 +132,7 @@ class PolyphaseRateFilter( IB, IRate, IReset, IS ) :
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
@@ -195,7 +195,7 @@ class PolyphaseRateFilter( IB, IRate, IReset, IS ) :
 
         if ( ( len( x.shape ) != 1 ) or ( len( x ) == 0 ) ) :
 
-            raise ValueError( 'X = ' + str( x ) )
+            raise ValueError( f'X = {x}' )
 
         y = numpy.zeros( int( numpy.ceil( len( x ) * self.rate ) ) )
 
@@ -243,7 +243,7 @@ class PolyphaseRateFilter( IB, IRate, IReset, IS ) :
 
         if ( not numpy.isscalar( x ) ) :
 
-            raise ValueError( 'X = ' + str( x ) )
+            raise ValueError( f'X = {x}' )
 
         if ( len( self.s ) > 1 ) :
 
