@@ -37,7 +37,7 @@
 
     **License**
 
-        `BSD-3C. <https://github.com/larryturner/diamondback/blob/master/license>`_
+        `BSD-3C.  <https://github.com/larryturner/diamondback/blob/master/license>`_
 
         Copyright (c) 2018, Larry Turner, Schneider Electric.  All rights reserved.
 
@@ -71,13 +71,13 @@ class RankFilter( FirFilter ) :
 
         if ( ( rank < 0 ) or ( rank > ( len( self.s ) - 1 ) ) ) :
 
-            raise ValueError( 'Rank = ' + str( rank ) )
+            raise ValueError( f'Rank = {rank}' )
 
         self._rank = rank
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
@@ -103,7 +103,7 @@ class RankFilter( FirFilter ) :
 
         if ( ( rank < 0 ) or ( rank > order ) ) :
 
-            raise ValueError( '{:30s}{:30s}'.format( 'Rank = ' + str( rank ), 'Order = ' + str( order ) ) )
+            raise ValueError( f'Rank = {rank} Order = {order}' )
 
         super( ).__init__( numpy.ones( order + 1 ) / ( order + 1 ) )
 
@@ -128,7 +128,7 @@ class RankFilter( FirFilter ) :
 
         if ( ( len( x.shape ) != 1 ) or ( len( x ) == 0 ) ) :
 
-            raise ValueError( 'X = ' + str( x ) )
+            raise ValueError( f'X = {x}' )
 
         y = numpy.zeros( len( x ), type( x[ 0 ] ) )
 
