@@ -24,7 +24,7 @@
 
     **License**
 
-        `BSD-3C. <https://github.com/larryturner/diamondback/blob/master/license>`_
+        `BSD-3C.  <https://github.com/larryturner/diamondback/blob/master/license>`_
 
         Copyright (c) 2018, Larry Turner, Schneider Electric.  All rights reserved.
 
@@ -58,7 +58,7 @@ class IDate( IEqual ) :
 
         if ( not date ) :
 
-            raise ValueError( 'Date = ' + str( date ) )
+            raise ValueError( f'Date = {date}' )
 
         if ( not date.tzinfo ) :
 
@@ -68,7 +68,7 @@ class IDate( IEqual ) :
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
