@@ -23,7 +23,7 @@
 
     **License**
 
-        `BSD-3C. <https://github.com/larryturner/diamondback/blob/master/license>`_
+        `BSD-3C.  <https://github.com/larryturner/diamondback/blob/master/license>`_
 
         Copyright (c) 2018, Larry Turner, Schneider Electric.  All rights reserved.
 
@@ -47,7 +47,7 @@ class IDuration( IEqual ) :
     @property
     def duration( self ) :
 
-        """ Duration in seconds ( float ).
+        """ Duration in seconds in [ 0.0, inf ) ( float ).
         """
 
         return self._duration
@@ -57,13 +57,13 @@ class IDuration( IEqual ) :
 
         if ( duration < 0.0 ) :
 
-            raise ValueError( 'Duration = ' + str( duration ) )
+            raise ValueError( f'Duration = {duration}' )
 
         self._duration = duration
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
