@@ -15,15 +15,15 @@
 
                     super( ).__init__( )
 
-                    self.encoding = ( )
+                    self.encoding = 'utf-8'
 
             test = Test( )
 
-            test.encoding = ( 0.0, 1.0 )
+            test.encoding = 'utf-16'
 
     **License**
 
-        `BSD-3C. <https://github.com/larryturner/diamondback/blob/master/license>`_
+        `BSD-3C.  <https://github.com/larryturner/diamondback/blob/master/license>`_
 
         Copyright (c) 2019, Larry Turner, Schneider Electric.  All rights reserved.
 
@@ -58,7 +58,7 @@ class IEncoding( IEqual ) :
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
