@@ -23,7 +23,7 @@
 
     **License**
 
-        `BSD-3C. <https://github.com/larryturner/diamondback/blob/master/license>`_
+        `BSD-3C.  <https://github.com/larryturner/diamondback/blob/master/license>`_
 
         Copyright (c) 2018, Larry Turner, Schneider Electric.  All rights reserved.
 
@@ -57,13 +57,13 @@ class IFrequency( IEqual ) :
 
         if ( ( frequency < -1.0 ) or ( frequency > 1.0 ) ) :
 
-            raise ValueError( 'Frequency = ' + str( frequency ) )
+            raise ValueError( f'Frequency = {frequency}' )
 
         self._frequency = frequency
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
