@@ -47,7 +47,7 @@ class IInterval( IEqual ) :
     @property
     def interval( self ) :
 
-        """ Interval in seconds ( float ).
+        """ Interval in seconds in [ 0.0, inf ) ( float ).
         """
 
         return self._interval
@@ -57,13 +57,13 @@ class IInterval( IEqual ) :
 
         if ( interval < 0.0 ) :
 
-            raise ValueError( 'Interval = ' + str( interval ) )
+            raise ValueError( f'Interval = {interval}' )
 
         self._interval = interval
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
