@@ -46,7 +46,7 @@ class ILatency( IEqual ) :
     @property
     def latency( self ) :
 
-        """ Latency in seconds ( float ).
+        """ Latency in seconds in [ 0.0, inf ) ( float ).
         """
 
         return self._latency
@@ -56,13 +56,13 @@ class ILatency( IEqual ) :
 
         if ( latency < 0.0 ) :
 
-            raise ValueError( 'Latency = ' + str( latency ) )
+            raise ValueError( f'Latency = {latency}' )
 
         self._latency = latency
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
