@@ -59,13 +59,13 @@ class IPath( IEqual ) :
 
             if ( not os.path.exists( path ) ) :
 
-                raise FileNotFoundError( 'Path = ' + str( path ) )
+                raise FileNotFoundError( f'Path = {path}' )
 
         self._path = path
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
