@@ -47,7 +47,7 @@ class IPeriod( IEqual ) :
     @property
     def period( self ) :
 
-        """ Period in seconds ( float ).
+        """ Period in seconds in [ 0.0, inf ) ( float ).
         """
 
         return self._period
@@ -57,13 +57,13 @@ class IPeriod( IEqual ) :
 
         if ( period < 0.0 ) :
 
-            raise ValueError( 'Period = ' + str( period ) )
+            raise ValueError( f'Period = {period}' )
 
         self._period = period
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
