@@ -57,13 +57,13 @@ class IPhase( IEqual ) :
 
         if ( ( phase < -1.0 ) or ( phase > 1.0 ) ) :
 
-            raise ValueError( 'Phase = ' + str( phase ) )
+            raise ValueError( f'Phase = {phase}' )
 
         self._phase = phase
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
