@@ -23,7 +23,7 @@
 
     **License**
 
-        `BSD-3C. <https://github.com/larryturner/diamondback/blob/master/license>`_
+        `BSD-3C.  <https://github.com/larryturner/diamondback/blob/master/license>`_
 
         Copyright (c) 2018, Larry Turner, Schneider Electric.  All rights reserved.
 
@@ -47,7 +47,7 @@ class IRate( IEqual ) :
     @property
     def rate( self ) :
 
-        """ Rate of adaptation ( float ).
+        """ Rate of adaptation in [ 0.0, inf ) ( float ).
         """
 
         return self._rate
@@ -57,13 +57,13 @@ class IRate( IEqual ) :
 
         if ( rate < 0.0 ) :
 
-            raise ValueError( 'Rate = ' + str( rate ) )
+            raise ValueError( f'Rate = {rate}' )
 
         self._rate = rate
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
