@@ -47,7 +47,7 @@ class IResolution( IEqual ) :
     @property
     def resolution( self ) :
 
-        """ Resolution ( float ).
+        """ Resolution in ( 0.0, inf ) ( float ).
         """
 
         return self._resolution
@@ -57,13 +57,13 @@ class IResolution( IEqual ) :
 
         if ( resolution <= 0.0 ) :
 
-            raise ValueError( 'Resolution = ' + str( resolution ) )
+            raise ValueError( f'Resolution = {resolution}' )
 
         self._resolution = resolution
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
