@@ -6,9 +6,9 @@
 
         ::
 
+            from dateutil import tz
             from diamondback import ITimeZone
             import datetime
-            import pytz
 
 
             class Test( ITimeZone ) :
@@ -21,11 +21,11 @@
 
             test = Test( )
 
-            test.timezone = pytz.timezone( 'US/Eastern' )
+            test.timezone = tz.gettz( 'US/Eastern' )
 
     **License**
 
-        `BSD-3C. <https://github.com/larryturner/diamondback/blob/master/license>`_
+        `BSD-3C.  <https://github.com/larryturner/diamondback/blob/master/license>`_
 
         Copyright (c) 2018, Larry Turner, Schneider Electric.  All rights reserved.
 
@@ -59,13 +59,13 @@ class ITimeZone( IEqual ) :
 
         if ( not timezone ) :
 
-            raise ValueError( 'TimeZone = ' + str( timezone ) )
+            raise ValueError( f'TimeZone = {timezone}' )
 
         self._timezone = timezone
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
