@@ -54,17 +54,15 @@ class IUrl( IEqual ) :
     @url.setter
     def url( self, url : str ) :
 
-        url = url.strip( '/' )
+        if ( url ) :
 
-        if ( not url ) :
-
-            raise ValueError( 'Url = ' + str( url ) )
+            url = url.strip( '/' )
 
         self._url = url
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
