@@ -60,7 +60,7 @@ class IUser( IEqual ) :
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
