@@ -72,7 +72,7 @@
 
     **License**
 
-        `BSD-3C. <https://github.com/larryturner/diamondback/blob/master/license>`_
+        `BSD-3C.  <https://github.com/larryturner/diamondback/blob/master/license>`_
 
         Copyright (c) 2018, Larry Turner, Schneider Electric.  All rights reserved.
 
@@ -126,21 +126,21 @@ class DiversityModel( IClear, IS, IEqual ) :
 
             if ( ( not typ ) or ( not issubclass( typ, DiversityModel ) ) ) :
 
-                raise ValueError( 'Type = ' + str( typ ) )
+                raise ValueError( f'Type = {typ}' )
 
             if ( ( not classification ) or ( classification not in DiversityModel.Factory._distance ) ) :
 
-                raise ValueError( 'Classification = ' + str( classification ) )
+                raise ValueError( f'Classification = {classification}' )
 
             if ( order <= 0 ) :
 
-                raise ValueError( 'Order = ' + str( order ) )
+                raise ValueError( f'Order = {order}' )
 
             return typ( DiversityModel.Factory._distance[ classification ], order )
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
@@ -166,7 +166,7 @@ class DiversityModel( IClear, IS, IEqual ) :
 
         if ( ( not distance ) or ( isinstance( distance, str ) ) ) :
 
-            raise ValueError( 'Distance = ' + str( distance ) )
+            raise ValueError( f'Distance = {distance}' )
 
         super( ).__init__( )
 
@@ -198,7 +198,7 @@ class DiversityModel( IClear, IS, IEqual ) :
 
         if ( ( len( x.shape ) > 2 ) or ( len( x ) == 0 ) ) :
 
-            raise ValueError( 'X = ' + str( x ) )
+            raise ValueError( f'X = {x}' )
 
         if ( len( x.shape ) < 2 ) :
 
@@ -214,7 +214,7 @@ class DiversityModel( IClear, IS, IEqual ) :
 
         if ( ( rows != self.s.shape[ 0 ] ) or ( cols <= 0 ) ) :
 
-            raise ValueError( '{:30s}{:30s}'.format( 'Rows = ' + str( rows ), 'Columns = ' + str( cols ) ) )
+            raise ValueError( f'Rows = {rows} Colums = {cols}' )
 
         cc = 0
 
