@@ -57,7 +57,7 @@
 
     **License**
 
-        `BSD-3C. <https://github.com/larryturner/diamondback/blob/master/license>`_
+        `BSD-3C.  <https://github.com/larryturner/diamondback/blob/master/license>`_
 
         Copyright (c) 2019, Larry Turner, Schneider Electric.  All rights reserved.
 
@@ -106,7 +106,7 @@ class PrincipalComponentModel( IClear, IS, IEqual ) :
 
     def __eq__( self, other : any ) -> bool :
 
-        """ Equality.
+        """ Equal.
 
             Arguments :
 
@@ -154,7 +154,7 @@ class PrincipalComponentModel( IClear, IS, IEqual ) :
 
         if ( ( len( x.shape ) != 2 ) or ( len( x ) == 0 ) ) :
 
-            raise ValueError( 'X = ' + str( x ) )
+            raise ValueError( f'X = {x}' )
 
         if ( not len( self.s ) ) :
 
@@ -174,6 +174,6 @@ class PrincipalComponentModel( IClear, IS, IEqual ) :
 
         if ( ( rows != len( self._u ) ) or ( ( rows, rows ) != self._v.shape ) or ( cols <= 0 ) ):
 
-            raise ValueError( '{:30s}{:30s}'.format( 'Rows = ' + str( rows ), 'Columns = ' + str( cols ) ) )
+            raise ValueError( f'Rows = {rows} Columns = {cols}' )
 
         return numpy.matmul( self.v, z )
