@@ -58,29 +58,31 @@
 
         * | 'Symmlet' is nearly symmetric, high quality, with order in [ 7 : 19 : 2 ].
 
-    **Example** ::
+    **Example**
 
-        from diamondback import WaveletTransform
-        import numpy
+        ::
+
+            from diamondback import WaveletTransform
+            import numpy
 
 
-        count = 3
+            count = 3
 
-        # Create an instance from a Factory with constraints.
+            # Create an instance from a Factory with constraints.
 
-        obj = WaveletTransform.Factory.instance( typ = WaveletTransform, classification = 'Haar', order = 1 )
+            obj = WaveletTransform.Factory.instance( typ = WaveletTransform, classification = 'Haar', order = 1 )
 
-        x = numpy.random.rand( 2**( count + 3 ), 2**( count + 3 ) )
+            x = numpy.random.rand( 2**( count + 3 ), 2**( count + 3 ) )
 
-        # Transform an incident signal, forward and inverse.
+            # Transform an incident signal, forward and inverse.
 
-        y = obj.transform( x, count, False )
+            y = obj.transform( x, count, False )
 
-        z = obj.transform( y, count, True )
+            z = obj.transform( y, count, True )
 
     **License**
 
-        `BSD-3C. <https://github.com/larryturner/diamondback/blob/master/license>`_
+        `BSD-3C.  <https://github.com/larryturner/diamondback/blob/master/license>`_
 
         Copyright (c) 2018, Larry Turner, Schneider Electric.  All rights reserved.
 
@@ -209,17 +211,17 @@ class WaveletTransform( IB, IEqual ) :
 
             if ( ( not typ ) or ( not issubclass( typ, WaveletTransform ) ) ) :
 
-                raise ValueError( 'Type = ' + str( typ ) )
+                raise ValueError( f'Type = {typ}' )
 
             if ( classification not in WaveletTransform.Factory._b ) :
 
-                raise ValueError( 'Classification = ' + str( classification ) )
+                raise ValueError( f'Classification = {classification}' )
 
             b = WaveletTransform.Factory._b[ classification ]
 
             if ( order not in b ) :
 
-                raise ValueError( 'Order = ' + str( order ) )
+                raise ValueError( f'Order = {order}' )
 
             return typ( b[ order ] )
 
@@ -238,7 +240,7 @@ class WaveletTransform( IB, IEqual ) :
 
         if ( ( len( b.shape ) != 1 ) or ( len( b ) == 0 ) ) :
 
-            raise ValueError( 'B = ' + str( b ) )
+            raise ValueError( f'B = {b}' )
 
         super( ).__init__( )
 
@@ -294,7 +296,7 @@ class WaveletTransform( IB, IEqual ) :
 
         if ( ( len( x.shape ) > 2 ) or ( len( x ) == 0 ) ) :
 
-            raise ValueError( 'X = ' + str( x ) )
+            raise ValueError( f'X = {x}' )
 
         if ( len( x.shape ) == 2 ) :
 
@@ -308,11 +310,11 @@ class WaveletTransform( IB, IEqual ) :
 
         if ( count <= 0 ) :
 
-            raise ValueError( 'Count = ' + str( count ) )
+            raise ValueError( f'Count = {count}' )
 
         if ( ( ( rows != 1 ) and ( rows % ( 2 ** count ) ) ) or ( ( cols != 1 ) and ( cols % ( 2 ** count ) ) ) ) :
 
-            raise ValueError( '{:30s}{:30s}'.format( 'Rows = ' + str( rows ), 'Columns = ' + str( cols ) ) )
+            raise ValueError( f'Rows = {rows} Columns = {cols}' )
 
         rr = max( ( rows // ( 2 ** count ) ) * ( 2 ** count ), 1 )
 
@@ -334,7 +336,7 @@ class WaveletTransform( IB, IEqual ) :
 
                         firfilter[ kk ].s[ : ] = 0.0
 
-                        u = firfilter[ kk ].filter( v[ ii, 0 : cc ] )[ 0 ]
+                        u = firfilter[ kk ].filter( v[ ii, 0 : cc ] )
 
                         y[ ii, kk * ( cc // 2 ) : ( kk + 1 ) * ( cc // 2 ) ] = u[ 1 : : 2 ]
 
@@ -348,7 +350,7 @@ class WaveletTransform( IB, IEqual ) :
 
                         firfilter[ kk ].s[ : ] = 0.0
 
-                        u = firfilter[ kk ].filter( v[ 0 : rr, jj ] )[ 0 ]
+                        u = firfilter[ kk ].filter( v[ 0 : rr, jj ] )
 
                         y[ kk * ( rr // 2 ) : ( kk + 1 ) * ( rr // 2 ), jj ] = u[ 1 : : 2 ]
 
@@ -384,7 +386,7 @@ class WaveletTransform( IB, IEqual ) :
 
                         firfilter[ kk ].s[ : ] = 0.0
 
-                        w += 2.0 * firfilter[ kk ].filter( u )[ 0 ]
+                        w += 2.0 * firfilter[ kk ].filter( u )
 
                     y[ 0 : rr, jj ] = w
 
@@ -402,7 +404,7 @@ class WaveletTransform( IB, IEqual ) :
 
                         firfilter[ kk ].s[ : ] = 0.0
 
-                        w += 2.0 * firfilter[ kk ].filter( u )[ 0 ]
+                        w += 2.0 * firfilter[ kk ].filter( u )
 
                     y[ ii, 0 : cc ] = w
 
